const svg = d3.select('svg');
const projection = d3.geoMercator();
let currentSimplyThd = 0; 

d3.json('https://gist.githubusercontent.com/yasmeenha/8a5bd0abe3b789b388e8b46dbde4ad4b/raw/3aef5908c6a5725aa6bf604ed2821be544f59c1c/jjapan.csv', function(json) {
	//Add data for simplicity (the area of a triangle connecting three adjacent points)
	const presimplify = topojson.presimplify(json);
	//topjson->geojson
	const geojson = topojson.feature(presimplify, presimplify.objects.japan);
	//Execution of drawing process
	draw(geojson, currentSimplyThd);
	
	const reDraw = draw.bind(null, geojson);
	
	
	d3.select("#range").on("input", function(){
		currentSimplyThd = this.value;
		reDraw(currentSimplyThd);
	});
	
	d3.select(window).on("resize", function(){
		reDraw(currentSimplyThd);
	});
	
});


//Draw the terrain
function draw(geojson, threshold){
	const w = svg.node().clientWidth;
	const h = svg.node().clientHeight;
	
	projection.fitExtent([[0, 0], [w, h]], geojson);
	
	//Set up custom stream listeners for simplicity
	const simplify= d3.geoTransform({
		point: function(x, y, z) {
			//Convert only those areas connected by three adjacent points above the threshold to pixel coordinates
			if (z >= threshold)  this.stream.point(projection([x, y]));
		} 
	});
	
	//Generate a function to convert a collection of pixcel coordinates to a path data format passed to the attribute of the path element		
	const path = d3.geoPath().projection(simplify);　
	
	
	//Add a path element
	const updateMaps= svg.selectAll('.map').data([geojson])
	const enterMaps = updateMaps.enter()
		.append("path")
		.attr("class", "map")
		.attr("fill", "green")
		.attr("stroke", "black")

	updateMaps.merge(enterMaps)
		.attr("d", path)
		